===================
Datetime / Duration
===================

.. currentmodule:: pydiverse.transform.ColExpr
.. autosummary::
    :toctree: _generated/
    :nosignatures:
    :template: accessor_method.rst

    dt.day
    dt.day_of_week
    dt.day_of_year
    dt.hour
    dt.microsecond
    dt.millisecond
    dt.minute
    dt.month
    dt.second
    dt.year
    dur.days
    dur.hours
    dur.microseconds
    dur.milliseconds
    dur.minutes
    dur.seconds
